@@ -21,7 +21,7 @@ class Network3Medusa():
         self.py2output()
 
     def py2output(self):
-        output = subprocess.Popen(["python", "show_version.py", f'--"{ self.command }"'])
+        output = subprocess.call(["python", "call_clid.py", self.command])
         print(output)
         return(output)
 
